# About

Passphrase is a zero-dependency passphrase generator.

## Background

I was using Bitwarden's passphrase generator, which is good,
except it only uses English words, and is also very slow.
So I made this one. It's pretty fast
(over 6000 times faster than `bw generate -p`,)
and you can use any wordlist.
An English wordlist is included, and is the default.

## Building

The program is written in [Zig](https://ziglang.org) 0.6.0,
so you will need the Zig compiler,
which is called `zig` in most package managers.

To build and install the program:

```shell
zig build -Drelease-fast --prefix ~/.local
```

It installs an executable file in `$PREFIX/bin`,
so that should be in your `$PATH`.

To run the tests:

```shell
zig build test
```

## Usage

Use `pp -h` to see the available options.
Some examples:

```shell
pp
demontering-vestlandsturnear-pacemen

pp -x # add a random symbol
intimacy-urvriden-overprest$

pp -d # add a random digit
folkinitiativ-elefantritt-felfinneri0

pp -c # capitalise each word
Alligator-Eignarlandi-Armkraft

pp -s _ # change the separator
afdreginni_glaskasse_opplevingi

pp -s '' # use an empty separator
tansprungephantasmagoriandeviancy

pp -w 6 # it should have 6 words
dobbeltleveranse-skunkworks-kubikfot-veggtavlone-freeridden-polarimeter

pp -f path/to/english_words.txt # use different dictionary
likelihood-impassible-educational

pp -xdcs /
Batwomen/Velopharyngeal/Bildekort&9
```

If the output is piped into another command,
for example `pp | wl-copy` to put the passphrase in the clipboard,
the ending newline is omitted, so that it can be safely pasted.
