const builtin = @import("builtin");
const std = @import("std");
const mem = std.mem;
const fs = std.fs;
const Builder = std.build.Builder;
const Target = std.build.Target;
const program_name = @import("src/options.zig").program_name;
const dict_file = @import("src/main.zig").dict_file;
const sep = fs.path.sep_str;

pub fn build(b: *Builder) !void {
    const mode = b.standardReleaseOptions();
    const exe = b.addExecutable(program_name, "src" ++ sep ++ "main.zig");
    const tests = b.addTest("src" ++ sep ++ "tests.zig");
    exe.setBuildMode(mode);
    exe.single_threaded = true;
    exe.link_function_sections = true;

    if (mode != .Debug)
        exe.strip = true;

    if (mode == .ReleaseSafe)
        exe.force_pic = true;

    b.default_step.dependOn(&exe.step);
    b.installArtifact(exe);

    b.installFile(
        "share" ++ sep ++ dict_file,
        "share" ++ sep ++ program_name ++ sep ++ dict_file,
    );

    b.installFile(
        program_name ++ ".1",
        "man" ++ sep ++ "man1" ++ sep ++ program_name ++ ".1",
    );

    const run_cmd = exe.run();
    const run_step = b.step("run", "Run " ++ program_name);

    const test_step = b.step("test", "Run all " ++ program_name ++ " tests");
    test_step.dependOn(&tests.step);

    run_step.dependOn(&run_cmd.step);
}
